]> Gitweb @ Texas Instruments - Open Source Git Repositories - git.TI.com/gitweb - keystone-rtos/osal.git/commitdiff
PRSDK-6460: Fixing doxygen warnings DEV.OSAL.01.00.00.16A
authorMahesh Radhakrishnan <m-radhakrishnan2@ti.com>
Thu, 3 Oct 2019 16:58:25 +0000 (12:58 -0400)
committerAnkur <a0132173@ti.com>
Fri, 4 Oct 2019 09:23:44 +0000 (04:23 -0500)
14 files changed:
CacheP.h
EventCombinerP.h
EventP.h
HwiP.h
MuxIntcP.h
Queue.h
RegisterIntr.h
SemaphoreP.h
SwiP.h
TimerP.h
docs/Doxyfile
docs/doxyfile.xdt
osal.h
osalver.h

index f6996c09db0eac799bf514385cf496f459060b33..0031e0bc875655a997eb396d0b76f0e49de422fd 100644 (file)
--- a/CacheP.h
+++ b/CacheP.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_CacheP CacheP
+ *            CacheP interface
+ *
+ *  @{
+ */ 
 /** ============================================================================
  *  @file       CacheP.h
  *
@@ -87,3 +96,4 @@ extern void CacheP_wbInv(const void * addr, int32_t size);
 #endif
 
 #endif /* ti_osal_CacheP__include */
+/* @} */
index 7133b95caa2b08e51186ede3de1e1226a276c31c..5557f98515612b83fe53d63471896951431623b2 100755 (executable)
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_EventCombinerP EventCombinerP
+ *            EventCombinerP interface
+ *
+ *  @{
+ */ 
+  
 /** ============================================================================
  *  @file       EventCombinerP.h
  *
@@ -137,3 +148,4 @@ int32_t EventCombinerP_GroupRegisterInt(int32_t intNum[]);
 #endif
 
 #endif /* ti_osalEventCombinerP__include */
+/* @} */
index cda0bb5f9bc952148fb2207798618247b4a7fbdc..2483b09c51d8c897fd831922c75e78bc16607968 100644 (file)
--- a/EventP.h
+++ b/EventP.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_EventP EventP
+ *            EventP interface
+ *
+ *  @{
+ */ 
 /** ============================================================================
  *  @file       EventP.h
  *
@@ -203,3 +212,4 @@ extern uint32_t EventP_getPostedEvents(EventP_Handle handle);
 #endif
 
 #endif /* ti_osal_EventP__include */
+/* @} */
diff --git a/HwiP.h b/HwiP.h
index 5f038dbf3f6db8776f61d9afa5b9d7f294d4d5d3..092d6ea7b808bdcfdef82c30a03094e707ffd4df 100644 (file)
--- a/HwiP.h
+++ b/HwiP.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_HwiP HwiP
+ *            HWIP interface
+ *
+ *  @{
+ */
+
 /** ============================================================================
  *  @file       HwiP.h
  *
@@ -167,7 +175,7 @@ extern HwiP_Handle HwiP_create(int32_t interruptNum, HwiP_Fxn hwiFxn,
 /*!
  *  @brief  Function to delete an interrupt on CortexM devices
  *
- *  @param  handle returned from the HwiP_create call
+ *  @param  hwiPhandle returned from the HwiP_create call
  *
  *  @return A HwiP_Handle on success or a NULL
  */
@@ -248,3 +256,4 @@ extern int32_t HwiP_post(uint32_t interruptNum);
 #endif
 
 #endif /* ti_osal_HwiP__include */
+/* @} */
index eaf44d5b3502b99d5f244366782e547aefe65713..70c1700bf3d61d459dbac3ec2e7248accd7ee5ef 100644 (file)
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_MuxIntcP MuxIntcP
+ *            MuxIntcP interface
+ *
+ *  @{
+ */ 
 /** ============================================================================
  *  @file       MuxIntcP.h
  *
@@ -153,3 +160,4 @@ extern void MuxIntcP_disableOutEvent(int32_t muxNum, int32_t muxOutEvent);
 #endif
 
 #endif /* ti_osal_MuxIntcP__include */
+/* @} */
diff --git a/Queue.h b/Queue.h
index ac03e707c7a0df2d72a8b88d2adaf38ce2b7b242..88e46f98e476ffc064c00495466ed17c058b7504 100644 (file)
--- a/Queue.h
+++ b/Queue.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_Queue Queue
+ *            Queue interface
+ *
+ *  @{
+ */ 
 /** ============================================================================
  *  @file       Queue.h
  *
@@ -104,7 +113,7 @@ void * Osal_Queue_get(Osal_Queue_Handle queueHandle);
  *
  *  @param  queueHandle   The queue handle
  *
- *  @param  Ptr      Pointer to the queue element 
+ *  @param  ptr      Pointer to the queue element 
  */
 void Osal_Queue_put(Osal_Queue_Handle queueHandle,Osal_Queue_Elem *ptr);
 
@@ -113,3 +122,4 @@ void Osal_Queue_put(Osal_Queue_Handle queueHandle,Osal_Queue_Elem *ptr);
 #endif
 
 #endif /* ti_osal_CacheP__include */
+/* @} */
index 5b4988daf85fd7e63539e19fb71951db851062bf..4e915ff28b262773bf127f981f87d5e697f0cd3c 100755 (executable)
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_RegisterIntr RegisterIntr
+ *            RegisterIntr interface
+ *
+ *  @{
+ */
 /** ============================================================================
  *  @file       RegisterIntr.h
  *
@@ -146,3 +153,4 @@ void Osal_ClearInterrupt(int32_t corepacEvent,int32_t interruptNum);
 #endif
 
 #endif /* ti_osal_RegisterIntr__include */
+/* @} */
index 8a33ab66c096d45704f3f27fcf8a1c8a613bc10a..2f35ebe353a1b4b61e538bbda392f1237b90d794 100644 (file)
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_SemaphoreP SemaphoreP
+ *            SemaphoreP interface
+ *
+ *  @{
+ */
+
 /** ============================================================================
  *  @file       SemaphoreP.h
  *
@@ -238,3 +247,4 @@ extern SemaphoreP_Status SemaphoreP_reset(SemaphoreP_Handle semPhandle);
 #endif
 
 #endif /* ti_osal_SemaphoreP__include */
+/* @} */
--- a/TimerP.h
+++ b/TimerP.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_TimerP TimerP
+ *            TimerP interface
+ *
+ *  @{
+ */
+
 /** ============================================================================
  *  @file       TimerP.h
  *
@@ -293,3 +302,4 @@ extern uint64_t TimerP_getTimeInUsecs(void);
 #endif
 
 #endif /* ti_osal_ClockP__include */
+/* @} */
index 805b43bc056913ee3e35b7b48589c0d572726285..4412750998ef9ec1e9262e69d61b0703dfb21a12 100644 (file)
@@ -6,7 +6,7 @@
 #---------------------------------------------------------------------------
 DOXYFILE_ENCODING      = UTF-8
 PROJECT_NAME           = "OSAL Library"
-PROJECT_NUMBER         = 1.0.0.13
+PROJECT_NUMBER         = 1.0.0.16
 OUTPUT_DIRECTORY       = ./docs/doxygen
 CREATE_SUBDIRS         = NO
 OUTPUT_LANGUAGE        = English
@@ -32,7 +32,6 @@ SHORT_NAMES            = NO
 JAVADOC_AUTOBRIEF      = NO
 QT_AUTOBRIEF           = NO
 MULTILINE_CPP_IS_BRIEF = NO
-DETAILS_AT_TOP         = NO
 INHERIT_DOCS           = YES
 SEPARATE_MEMBER_PAGES  = NO
 TAB_SIZE               = 8
@@ -77,7 +76,6 @@ GENERATE_DEPRECATEDLIST= YES
 ENABLED_SECTIONS       = 
 MAX_INITIALIZER_LINES  = 30
 SHOW_USED_FILES        = YES
-SHOW_DIRECTORIES       = NO
 SHOW_FILES             = YES
 SHOW_NAMESPACES        = YES
 FILE_VERSION_FILTER    = 
@@ -139,7 +137,6 @@ HTML_FILE_EXTENSION    = .html
 HTML_HEADER            = ./docs/tiheader.htm
 HTML_FOOTER            = ./docs/tifooter.htm
 HTML_STYLESHEET        = 
-HTML_ALIGN_MEMBERS     = YES
 GENERATE_HTMLHELP      = YES
 GENERATE_DOCSET        = NO
 DOCSET_FEEDNAME        = "Doxygen generated docs"
@@ -233,7 +230,6 @@ CLASS_DIAGRAMS         = NO
 MSCGEN_PATH            = 
 HIDE_UNDOC_RELATIONS   = YES
 HAVE_DOT               = NO
-DOT_FONTNAME           = FreeSans
 DOT_FONTPATH           = 
 CLASS_GRAPH            = YES
 COLLABORATION_GRAPH    = YES
index c2c3fca2249d97fe27d450c37eb176a584411577..7bf5b5859d17a8daf2e526d53e0ccaea52818d65 100644 (file)
@@ -41,7 +41,6 @@ SHORT_NAMES            = NO
 JAVADOC_AUTOBRIEF      = NO\r
 QT_AUTOBRIEF           = NO\r
 MULTILINE_CPP_IS_BRIEF = NO\r
-DETAILS_AT_TOP         = NO\r
 INHERIT_DOCS           = YES\r
 SEPARATE_MEMBER_PAGES  = NO\r
 TAB_SIZE               = 8\r
@@ -86,7 +85,6 @@ GENERATE_DEPRECATEDLIST= YES
 ENABLED_SECTIONS       = \r
 MAX_INITIALIZER_LINES  = 30\r
 SHOW_USED_FILES        = YES\r
-SHOW_DIRECTORIES       = NO\r
 SHOW_FILES             = YES\r
 SHOW_NAMESPACES        = YES\r
 FILE_VERSION_FILTER    = \r
@@ -148,7 +146,6 @@ HTML_FILE_EXTENSION    = .html
 HTML_HEADER            = ./docs/tiheader.htm\r
 HTML_FOOTER            = ./docs/tifooter.htm\r
 HTML_STYLESHEET        = \r
-HTML_ALIGN_MEMBERS     = YES\r
 GENERATE_HTMLHELP      = YES\r
 GENERATE_DOCSET        = NO\r
 DOCSET_FEEDNAME        = "Doxygen generated docs"\r
@@ -242,7 +239,6 @@ CLASS_DIAGRAMS         = NO
 MSCGEN_PATH            = \r
 HIDE_UNDOC_RELATIONS   = YES\r
 HAVE_DOT               = NO\r
-DOT_FONTNAME           = FreeSans\r
 DOT_FONTPATH           = \r
 CLASS_GRAPH            = YES\r
 COLLABORATION_GRAPH    = YES\r
diff --git a/osal.h b/osal.h
index edd382d829224a3fec3c0c2ee70a290baacde8f7..e5e22d9e405539d661a02bb8212607e023354f3f 100644 (file)
--- a/osal.h
+++ b/osal.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+
+/**
+ *  \defgroup DRV_OSAL_MODULE OSAL
+ *
+ *  @{
+ */
+/* @} */
+
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_API OSAL_API
+ *            OSAL interface
+ *
+ *  @{
+ */
 /** ============================================================================
  *  @file       osal.h
  *
@@ -342,3 +357,4 @@ extern Osal_HwAttrs  gOsal_HwAttrs;
 #endif
 
 #endif /* ti_OSAL__include */
+/* @} */
index d5dc428cd864d338c0f02884dadeb6e7616f1450..2f7ca4d169dd471849297c040133868755c9b9a0 100644 (file)
--- a/osalver.h
+++ b/osalver.h
@@ -57,7 +57,7 @@ extern "C" {
  * @brief   This is the version string which describes the OSAL driver along with
  * the date and build information.
  */
-#define OSAL_DRV_VERSION_STR                    "OSAL library Revision: 01.00.00.15"
+#define OSAL_DRV_VERSION_STR                    "OSAL library Revision: 01.00.00.16"
 
 
 #ifdef __cplusplus
diff --git a/SwiP.h b/SwiP.h
index 118f1e5a0bc288e2835c6ede6fac8c0a9020be93..6a4b73dd17c8433ced3a05d43cf06c7b053e39ef 100644 (file)
--- a/SwiP.h
+++ b/SwiP.h
  * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
  * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
+/**
+ *  \ingroup DRV_OSAL_MODULE
+ *  \defgroup DRV_OSAL_SwiP SwiP
+ *            SwiP interface
+ *
+ *  @{
+ */
 /** ============================================================================
  *  @file       SwiP.h
  *
@@ -88,41 +95,42 @@ typedef struct SwiP_Params_s {
  *
  *  @param  swiFxn entry function of the software interrupt
  *
*  @param  params    Pointer to the instance configuration parameters. NULL
  *                    denotes to use the default parameters. The SwiP default
  *                    parameters are noted in ::SwiP_Params_init.
  *
  *  @return SwiP_Handle
  */
-extern SwiP_Handle SwiP_create(SwiP_Fxn swiFxn, const SwiP_Params *params);
+extern SwiP_Handle SwiP_create(SwiP_Fxn swiFxn, const SwiP_Params *swiPparams);
 
 /*!
  *  @brief  Function to delete an interrupt on CortexM devices
  *
*  @param  pointer of the handle returned from the SwiP_create call
  *
- *  @return A SwiP_Handle on success or a NULL
+ *  @return SwiP_OK if successfull, SwiP_FAILURE if fail
  */
 extern SwiP_Status SwiP_delete(SwiP_Handle *pHandle);
 
 /*!
  *  @brief  Initialize params structure to default values.
  *
*  @param params  Pointer to the instance configuration parameters.
  */
-extern void SwiP_Params_init(SwiP_Params *params);
+extern void SwiP_Params_init(SwiP_Params *swiPparams);
 
 /*!
  *  @brief  Function to post the Swi interrupt
  *
- *  @param  interruptNum the interrupt number
+ *  @param  swiPhandle The swiP handle
  * 
  *  @return  SwiP_OK if successfull, SwiP_FAILURE if fail
  */
-extern SwiP_Status SwiP_post(SwiP_Handle handle);
+extern SwiP_Status SwiP_post(SwiP_Handle swiPhandle);
 
 #ifdef __cplusplus
 }
 #endif
 
 #endif /* ti_osal_SwiP__include */
+/* @} */
index e5a14d652f75ec159bedef7faac8c4cd778cc169..856293621a34de9dd3334b16e395b7076c9972d0 100644 (file)
@@ -88,41 +95,42 @@ typedef struct SwiP_Params_s {
  *  @param  swiFxn entry function of the software interrupt
  *
- *  @param  params    Pointer to the instance configuration parameters. NULL
+ *  @param  swiPparams    Pointer to the instance configuration parameters. NULL
  *                    denotes to use the default parameters. The SwiP default
  *                    parameters are noted in ::SwiP_Params_init.
@@ -88,41 +95,42 @@ typedef struct SwiP_Params_s {
  *  @brief  Function to delete an interrupt on CortexM devices
  *
- *  @param  pointer of the handle returned from the SwiP_create call
+ *  @param  pHandle pointer of the handle returned from the SwiP_create call
  *
@@ -88,41 +95,42 @@ typedef struct SwiP_Params_s {
  *  @brief  Initialize params structure to default values.
  *
- *  @param params  Pointer to the instance configuration parameters.
+ *  @param swiPparams  Pointer to the instance configuration parameters.
  */